import React from 'react';
import Taro from '@tarojs/taro';
import { View, Map } from '@tarojs/components';
import { getLocation } from '@/utils/authorize';
import iconPath from '@/assets/icons/marker.png';
import style from './style.module.less';

export default (props) => {
  const { location, onLocChange } = props;

  const [currentPos, setCurPos] = React.useState();
  const [lngLat, setLngLat] = React.useState([,]);

  const markers = React.useMemo(() => {
    if (!location && !currentPos) return [];
    
    let longitude, latitude;
    if (location) {
      const [lng, lat] = location.split(',');
      longitude = lng - 0;
      latitude = lat - 0;
    } else {
      longitude = currentPos.longitude;
      latitude = currentPos.latitude;
    }

    setLngLat([longitude, latitude]);

    return [{
      id: 1,
      longitude,
      latitude,
      iconPath,
      width: 17,
      height: 20
    }];
  }, [location, currentPos]);
  
  React.useEffect(() => {
    getLocation().then((res) => {
      setCurPos(res);
      onLocChange([res.longitude, res.latitude].join(','))
    }).catch((err) => {
      Taro.showToast({
        title: '定位失败',
        icon: 'none',
      })
    });
  }, []);
  
  return (
    <View className={style['map-wrapper']}>
      <Map
        longitude={lngLat[0]}
        latitude={lngLat[1]}
        markers={markers}
      ></Map>
    </View>
  )
}
