import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import Page from '@/layouts/index';
import { Cell, CellGroup, Field, Radio, RadioGroup } from '@antmjs/vantui';
import { getTaIssueApplyById } from '@/services/taissueapply';
import { getDtStr } from '@/utils/date';
import Issue from '../components/Issue';

// const today = new Date();
export default (props) => {

  const router = Taro.useRouter();
  const { id, applyType, issueId } = router.params;

  const [loading, setLoading] = React.useState(false);
  const [applyInfo, setApplyInfo] = React.useState({});

  React.useMemo(() => {
    switch (applyType) {
      case 'delay':
        Taro.setNavigationBarTitle('延期申请');
        break;
      case 'reject':
        Taro.setNavigationBarTitle('驳回申请');
        break;
      case 'verify':
        Taro.setNavigationBarTitle('审核申请');
        break;
      case 'end':
        Taro.setNavigationBarTitle('办结申请');
        break;
    }
  }, [applyType]);
  
  React.useEffect(() => {
    if (id) {
      setLoading(true);
      getTaIssueApplyById(id).then(res => {
        setApplyInfo(res);
        setLoading(false);
      }).catch(() => {
        setLoading(false);
      });
    }
  }, [id]);
  
  return (
    <Page loading={loading}>
      <Issue issueId={issueId} />
     
      <CellGroup style={{marginTop: '20px'}}>
        {
          applyInfo.applyType == 'delay' && (
            <Cell
              title="延期日期"
              value={applyInfo.content}
            />
          )
        }
        <Cell title="申请说明" />
        <Field
          readonly
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={applyInfo.remark}
        />
      </CellGroup>
     
      <CellGroup style={{marginTop: '20px'}}>
        <Cell
          title="审批结果"
          value={applyInfo.verifyStatus == 'pass' ? '通过' : '驳回'}
        />
        <Cell title="审批说明" />
        <Field
          readonly
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={applyInfo.verifyDesc}
        />
        <Cell
          title="审核日期"
          value={getDtStr(applyInfo.verifyDate)}
        />
      </CellGroup>
    </Page>
  )
}
