import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import Page from '@/layouts/index';
import { Cell, CellGroup, Field, Button, Radio, RadioGroup } from '@antmjs/vantui';
import { putTaIssueApply, getTaIssueApplyById } from '@/services/taissueapply';
import { warn } from '@/utils/message';
import Issue from '../components/Issue';

// const today = new Date();
export default (props) => {

  const router = Taro.useRouter();
  const { id, applyType, issueId } = router.params;

  const [loading, setLoading] = React.useState(false);
  const [applyInfo, setApplyInfo] = React.useState({});

  React.useMemo(() => {
    switch (applyType) {
      case 'delay':
        Taro.setNavigationBarTitle('延期审批');
        break;
      case 'reject':
        Taro.setNavigationBarTitle('驳回审批');
        break;
      case 'verify':
        Taro.setNavigationBarTitle('审核审批');
        break;
      case 'end':
        Taro.setNavigationBarTitle('办结审批');
        break;
    }
  }, [applyType]);

  
  const [submitting, setSubmitting] = React.useState(false);
  const [formData, setFormData] = React.useState({});

  const setFieldValue = (key, value) => {
    setFormData({
      ...formData,
      [key]: value,
    })
  }
  
  const onSubmit = () => {
    try {
      warn(!formData.verifyStatus, '请选择审批结果');
      warn(!formData.verifyDesc, '请填写审批说明');
    } catch (e) {
      return ;
    }

    const data = {
      ...applyInfo,
      ...formData
    }

    setSubmitting(true);
    putTaIssueApply(data.applyId, data).then(() => {
      Taro.navigateBack({delta: 1});
      setSubmitting(false);
    }).catch(() => {
      setSubmitting(false);
    })
  }
  
  React.useEffect(() => {
    if (id) {
      setLoading(true);
      getTaIssueApplyById(id).then(res => {
        setApplyInfo(res);
        setLoading(false);
      }).catch(() => {
        setLoading(false);
      });
    }
  }, [id]);
  
  return (
    <Page loading={loading}>
      <Issue issueId={issueId} />
     
      <CellGroup style={{marginTop: '20px'}}>
        {
          applyInfo.applyType == 'delay' && (
            <Cell
              title="延期日期"
              value={applyInfo.content}
            />
          )
        }
        <Cell title="申请说明" />
        <Field
          readonly
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={applyInfo.remark}
        />
      </CellGroup>
     
      <CellGroup style={{marginTop: '20px'}}>
        <Cell
          title="审批结果"
        >
          <RadioGroup
            direction="horizontal"
            value={formData.verifyStatus}
            onChange={(e) => setFieldValue('verifyStatus', e.detail)}
          >
            <Radio name="pass" checkedColor="var(--main-bg-color)">通过</Radio>
            <Radio name="reject" checkedColor="red">驳回</Radio>
          </RadioGroup>
        </Cell>
        <Cell title="审批说明" />
        <Field
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={formData.verifyDesc}
          onChange={(e) => setFieldValue('verifyDesc', e.detail)}
        />
      </CellGroup>
      <View style={{marginTop: '20px', padding: 'var(--main-space)'}}>
        <Button block type="primary" loading={submitting} onClick={onSubmit}>提交审批</Button>
      </View>
    </Page>
  )
}
